@@ -14,12 +14,10 @@
 #
 
 package GnuPG::SecretKey;
-use Any::Moose;
+use Moo;
 
 BEGIN { extends qw( GnuPG::PrimaryKey ) }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
