@@ -38,19 +38,7 @@ use vars qw( @ISA           @EXPORT
 	      texts                  file_match
 	    );
 
-
-for my $gpg qw(gpg gpg2) {
-    my $gpg_find = "which $gpg";
-    print "$gpg_find ... ";
-    system($gpg_find);
-    if ( $? != 0 ) {
-        die "gpg (GnuPG) not found";
-    } else { $gpg_program = $gpg; last }
-}
-
-$gnupg = GnuPG::Interface->new( gnupg_call  => $gpg_program,
-				passphrase  => 'test',
-			      );
+$gnupg = GnuPG::Interface->new( passphrase => 'test' );
 
 $gnupg->options->hash_init( homedir              => 'test',
 			    armor                => 1,
